@@ -221,7 +221,7 @@ static void ParseModule(const module_t *mod)
 
 int main(int argc, const char **argv)
 {
-    libvlc_instance_t *libvlc = libvlc_new(argc, argv);
+    libvlc_instance_t *libvlc = libvlc_new(argc - 1, argv + 1);
     if (!libvlc)
         return 1;
 
@@ -235,9 +235,9 @@ int main(int argc, const char **argv)
     module_t **max = &mod_list[modules];
 
     puts("#compdef vlc cvlc rvlc svlc mvlc qvlc nvlc\n"
-           "#This file is autogenerated by zsh.cpp"
-           "typeset -A opt_args"
-           "local context state line ret=1"
+           "#This file is autogenerated by zsh.cpp\n"
+           "typeset -A opt_args\n"
+           "local context state line ret=1\n"
            "local modules\n");
 
     printf("vlc_modules=\"");
