@@ -4,7 +4,7 @@
  * interface, such as message output.
  *****************************************************************************
  * Copyright (C) 1999, 2000 VLC authors and VideoLAN
- * $Id: 81ad15e3e659297e0982a375f7f3e6061ec92a42 $
+ * $Id: e98be12aab142e9901562ea952ee11f54e207f46 $
  *
  * Authors: Vincent Seguin <seguin@via.ecp.fr>
  *
@@ -90,11 +90,21 @@ struct intf_dialog_args_t
     struct interaction_dialog_t *p_dialog;
 };
 
-VLC_API int intf_Create( vlc_object_t *, const char * );
-#define intf_Create(a,b) intf_Create(VLC_OBJECT(a),b)
+VLC_API int intf_Create( playlist_t *, const char * );
 
 VLC_API void libvlc_Quit( libvlc_int_t * );
 
+static inline playlist_t *pl_Get( struct intf_thread_t *intf )
+{
+    return (playlist_t *)(intf->p_parent);
+}
+
+/**
+ * Retrieves the current input thread from the playlist.
+ * @note The returned object must be released with vlc_object_release().
+ */
+#define pl_CurrentInput(intf) (playlist_CurrentInput(pl_Get(intf)))
+
 /**
  * \defgroup vlc_subscription Log messages subscription
  * These functions deal with log messages.
@@ -105,7 +115,7 @@ VLC_API void libvlc_Quit( libvlc_int_t * );
  * Message logging callback signature.
  * \param data data pointer as provided to vlc_msg_SetCallback().
  * \param type message type (VLC_MSG_* values from enum vlc_log_type)
- * \param item meta informations
+ * \param item meta information
  * \param fmt format string
  * \param args format string arguments
  */
@@ -114,10 +124,6 @@ typedef void (*vlc_log_cb) (void *data, int type, const vlc_log_t *item,
 
 VLC_API void vlc_LogSet(libvlc_int_t *, vlc_log_cb cb, void *data);
 
-typedef struct msg_subscription { } msg_subscription_t;
-#define vlc_Subscribe(sub,cb,data) ((sub), (cb), (data))
-#define vlc_Unsubscribe(sub) ((void)(sub))
-
 /*@}*/
 
 #if defined( _WIN32 ) && !VLC_WINSTORE_APP
@@ -178,17 +184,17 @@ typedef enum vlc_dialog {
 
 #define EXTENSIONS_AUDIO_CSV "3ga", "669", "a52", "aac", "ac3", "adt", "adts", "aif", "aifc", "aiff", \
                          "amr", "aob", "ape", "awb", "caf", "dts", "flac", "it", "kar", \
-                         "m4a", "m4p", "m5p", "mka", "mlp", "mod", "mpa", "mp1", "mp2", "mp3", "mpc", "mpga", \
-                         "oga", "ogg", "oma", "opus", "qcp", "ra", "rmi", "s3m", "spx", "thd", "tta", \
+                         "m4a", "m4b", "m4p", "m5p", "mka", "mlp", "mod", "mpa", "mp1", "mp2", "mp3", "mpc", "mpga", "mus", \
+                         "oga", "ogg", "oma", "opus", "qcp", "ra", "rmi", "s3m", "sid", "spx", "thd", "tta", \
                          "voc", "vqf", "w64", "wav", "wma", "wv", "xa", "xm"
 
-#define EXTENSIONS_VIDEO_CSV "3g2", "3gp", "3gp2", "3gpp", "amv", "asf", "avi", "divx", "drc", "dv", \
+#define EXTENSIONS_VIDEO_CSV "3g2", "3gp", "3gp2", "3gpp", "amv", "asf", "avi", "bik", "divx", "drc", "dv", \
                              "f4v", "flv", "gvi", "gxf", "iso", \
                              "m1v", "m2v", "m2t", "m2ts", "m4v", "mkv", "mov",\
                              "mp2", "mp2v", "mp4", "mp4v", "mpe", "mpeg", "mpeg1", \
                              "mpeg2", "mpeg4", "mpg", "mpv2", "mts", "mtv", "mxf", "mxg", "nsv", "nuv", \
                              "ogg", "ogm", "ogv", "ogx", "ps", \
-                             "rec", "rm", "rmvb", "tod", "ts", "tts", "vob", "vro", \
+                             "rec", "rm", "rmvb", "rpl", "thp", "tod", "ts", "tts", "txd", "vob", "vro", \
                              "webm", "wm", "wmv", "wtv", "xesc"
 
 #define EXTENSIONS_AUDIO \
@@ -212,6 +218,7 @@ typedef enum vlc_dialog {
     "*.it;"  \
     "*.kar;" \
     "*.m4a;" \
+    "*.m4b;" \
     "*.m4p;" \
     "*.m5p;" \
     "*.mid;" \
@@ -224,6 +231,7 @@ typedef enum vlc_dialog {
     "*.mp3;" \
     "*.mpc;" \
     "*.mpga;" \
+    "*.mus;" \
     "*.oga;" \
     "*.ogg;" \
     "*.oma;" \
@@ -232,6 +240,7 @@ typedef enum vlc_dialog {
     "*.ra;" \
     "*.rmi;" \
     "*.s3m;" \
+    "*.sid;" \
     "*.spx;" \
     "*.thd;" \
     "*.tta;" \
@@ -244,13 +253,13 @@ typedef enum vlc_dialog {
     "*.xa;"  \
     "*.xm"
 
-#define EXTENSIONS_VIDEO "*.3g2;*.3gp;*.3gp2;*.3gpp;*.amv;*.asf;*.avi;*.bin;*.divx;*.drc;*.dv;*f4v;*.flv;*.gvi;*.gxf;*.iso;*.m1v;*.m2v;" \
+#define EXTENSIONS_VIDEO "*.3g2;*.3gp;*.3gp2;*.3gpp;*.amv;*.asf;*.avi;*.bik;*.bin;*.divx;*.drc;*.dv;*f4v;*.flv;*.gvi;*.gxf;*.iso;*.m1v;*.m2v;" \
                          "*.m2t;*.m2ts;*.m4v;*.mkv;*.mov;*.mp2;*.mp2v;*.mp4;*.mp4v;*.mpe;*.mpeg;*.mpeg1;" \
                          "*.mpeg2;*.mpeg4;*.mpg;*.mpv2;*.mts;*.mtv;*.mxf;*.mxg;*.nsv;*.nuv;" \
                          "*.ogg;*.ogm;*.ogv;*.ogx;*.ps;" \
-                         "*.rec;*.rm;*.rmvb;*.tod;*.ts;*.tts;*.vob;*.vro;*.webm;*.wm;*.wmv;*.wtv;*.xesc"
+                         "*.rec;*.rm;*.rmvb;*.rpl;*.thp;*.tod;*.ts;*.tts;*.txd;*.vob;*.vro;*.webm;*.wm;*.wmv;*.wtv;*.xesc"
 
-#define EXTENSIONS_PLAYLIST "*.asx;*.b4s;*.cue;*.ifo;*.m3u;*.m3u8;*.pls;*.ram;*.rar;*.sdp;*.vlc;*.xspf;*.wvx;*.zip;*.conf"
+#define EXTENSIONS_PLAYLIST "*.asx;*.b4s;*.cue;*.ifo;*.m3u;*.m3u8;*.pls;*.ram;*.rar;*.sdp;*.vlc;*.xspf;*.wax;*.wvx;*.zip;*.conf"
 
 #define EXTENSIONS_MEDIA EXTENSIONS_VIDEO ";" EXTENSIONS_AUDIO ";" \
                           EXTENSIONS_PLAYLIST
@@ -261,7 +270,8 @@ typedef enum vlc_dialog {
                             "*.jss;*.psb;" \
                             "*.rt;*.smi;*.txt;" \
                             "*.smil;*.stl;*.usf;" \
-                            "*.dks;*.pjs;*.mpl2;*.mks"
+                            "*.dks;*.pjs;*.mpl2;*.mks;" \
+                            "*.vtt"
 
 /** \defgroup vlc_interaction Interaction
  * \ingroup vlc_interface
