@@ -1,25 +1,25 @@
 /*****************************************************************************
  * a52tospdif.c : encapsulates A/52 frames into S/PDIF packets
  *****************************************************************************
- * Copyright (C) 2002, 2006 the VideoLAN team
- * $Id: 8ee261cebb28fe4ade9fb2bd9386a590c87c897f $
+ * Copyright (C) 2002, 2006 VLC authors and VideoLAN
+ * $Id: 2e4a820702e5882e4536f8bc006ce0dcb37693ab $
  *
  * Authors: Christophe Massiot <massiot@via.ecp.fr>
  *          Stéphane Borel <stef@via.ecp.fr>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; either version 2.1 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
  *****************************************************************************/
 
 /*****************************************************************************
@@ -49,7 +49,7 @@ vlc_module_begin ()
     set_category( CAT_AUDIO )
     set_subcategory( SUBCAT_AUDIO_MISC )
     set_description( N_("Audio filter for A/52->S/PDIF encapsulation") )
-    set_capability( "audio filter", 10 )
+    set_capability( "audio converter", 10 )
     set_callbacks( Create, NULL )
 vlc_module_end ()
 
@@ -86,7 +86,7 @@ static block_t *DoWork( filter_t * p_filter, block_t *p_in_buf )
     uint16_t i_frame_size = p_in_buf->i_buffer / 2;
     uint8_t * p_in = p_in_buf->p_buffer;
 
-    block_t *p_out_buf = filter_NewAudioBuffer( p_filter, AOUT_SPDIF_SIZE );
+    block_t *p_out_buf = block_Alloc( AOUT_SPDIF_SIZE );
     if( !p_out_buf )
         goto out;
     uint8_t * p_out = p_out_buf->p_buffer;
@@ -94,21 +94,19 @@ static block_t *DoWork( filter_t * p_filter, block_t *p_in_buf )
     /* Copy the S/PDIF headers. */
     if( p_filter->fmt_out.audio.i_format == VLC_CODEC_SPDIFB )
     {
-        vlc_memcpy( p_out, p_sync_be, 6 );
+        memcpy( p_out, p_sync_be, 6 );
         p_out[4] = p_in[5] & 0x7; /* bsmod */
-        p_out[6] = (i_frame_size >> 4) & 0xff;
-        p_out[7] = (i_frame_size << 4) & 0xff;
-        vlc_memcpy( &p_out[8], p_in, i_frame_size * 2 );
+        SetWBE( p_out + 6, i_frame_size << 4 );
+        memcpy( &p_out[8], p_in, i_frame_size * 2 );
     }
     else
     {
-        vlc_memcpy( p_out, p_sync_le, 6 );
+        memcpy( p_out, p_sync_le, 6 );
         p_out[5] = p_in[5] & 0x7; /* bsmod */
-        p_out[6] = (i_frame_size << 4) & 0xff;
-        p_out[7] = (i_frame_size >> 4) & 0xff;
+        SetWLE( p_out + 6, i_frame_size << 4 );
         swab( p_in, &p_out[8], i_frame_size * 2 );
     }
-    vlc_memset( p_out + 8 + i_frame_size * 2, 0,
+    memset( p_out + 8 + i_frame_size * 2, 0,
                 AOUT_SPDIF_SIZE - i_frame_size * 2 - 8 );
 
     p_out_buf->i_dts = p_in_buf->i_dts;
