@@ -1,24 +1,24 @@
 /*****************************************************************************
  * rawvideo.c: Pseudo video decoder/packetizer for raw video data
  *****************************************************************************
- * Copyright (C) 2001, 2002 the VideoLAN team
- * $Id: aa68f35d26d544db938187f36fe8cc78e20d0e05 $
+ * Copyright (C) 2001, 2002 VLC authors and VideoLAN
+ * $Id: 331c216346d069eb976e617fec6311ce2b7514f2 $
  *
  * Authors: Laurent Aimar <fenrir@via.ecp.fr>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; either version 2.1 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
  *****************************************************************************/
 
 /*****************************************************************************
@@ -37,15 +37,14 @@
  *****************************************************************************/
 struct decoder_sys_t
 {
-    /* Module mode */
-    bool b_packetizer;
-
     /*
      * Input properties
      */
-    size_t i_raw_size;
     bool b_invert;
-    plane_t planes[PICTURE_PLANE_MAX];
+
+    size_t size;
+    unsigned pitches[PICTURE_PLANE_MAX];
+    unsigned lines[PICTURE_PLANE_MAX];
 
     /*
      * Common properties
@@ -58,12 +57,7 @@ struct decoder_sys_t
  ****************************************************************************/
 static int  OpenDecoder   ( vlc_object_t * );
 static int  OpenPacketizer( vlc_object_t * );
-static void CloseDecoder  ( vlc_object_t * );
-
-static void *DecodeBlock  ( decoder_t *, block_t ** );
-
-static picture_t *DecodeFrame( decoder_t *, block_t * );
-static block_t   *SendFrame  ( decoder_t *, block_t * );
+static void CloseCommon   ( vlc_object_t * );
 
 /*****************************************************************************
  * Module descriptor
@@ -73,66 +67,35 @@ vlc_module_begin ()
     set_capability( "decoder", 50 )
     set_category( CAT_INPUT )
     set_subcategory( SUBCAT_INPUT_VCODEC )
-    set_callbacks( OpenDecoder, CloseDecoder )
+    set_callbacks( OpenDecoder, CloseCommon )
 
     add_submodule ()
     set_description( N_("Pseudo raw video packetizer") )
     set_capability( "packetizer", 100 )
-    set_callbacks( OpenPacketizer, CloseDecoder )
+    set_callbacks( OpenPacketizer, CloseCommon )
 vlc_module_end ()
 
-/*****************************************************************************
- * OpenDecoder: probe the decoder and return score
- *****************************************************************************/
-static int OpenDecoder( vlc_object_t *p_this )
+/**
+ * Common initialization for decoder and packetizer
+ */
+static int OpenCommon( decoder_t *p_dec )
 {
-    decoder_t *p_dec = (decoder_t*)p_this;
-    decoder_sys_t *p_sys;
+    const vlc_chroma_description_t *dsc =
+        vlc_fourcc_GetChromaDescription( p_dec->fmt_in.i_codec );
+    if( dsc == NULL || dsc->plane_count == 0 )
+        return VLC_EGENERIC;
 
-    switch( p_dec->fmt_in.i_codec )
+    if( p_dec->fmt_in.video.i_width <= 0 || p_dec->fmt_in.video.i_height == 0 )
     {
-        /* Planar YUV */
-        case VLC_CODEC_I444:
-        case VLC_CODEC_J444:
-        case VLC_CODEC_I422:
-        case VLC_CODEC_J422:
-        case VLC_CODEC_I420:
-        case VLC_CODEC_J420:
-        case VLC_CODEC_YV12:
-        case VLC_CODEC_YV9:
-        case VLC_CODEC_I411:
-        case VLC_CODEC_I410:
-        case VLC_CODEC_GREY:
-        case VLC_CODEC_YUVP:
-        case VLC_CODEC_NV12:
-        case VLC_CODEC_NV21:
-
-        /* Packed YUV */
-        case VLC_CODEC_YUYV:
-        case VLC_CODEC_YVYU:
-        case VLC_CODEC_UYVY:
-        case VLC_CODEC_VYUY:
-
-        /* RGB */
-        case VLC_CODEC_RGB32:
-        case VLC_CODEC_RGB24:
-        case VLC_CODEC_RGB16:
-        case VLC_CODEC_RGB15:
-        case VLC_CODEC_RGB8:
-        case VLC_CODEC_RGBP:
-            break;
-
-        default:
-            return VLC_EGENERIC;
+        msg_Err( p_dec, "invalid display size %dx%d",
+                 p_dec->fmt_in.video.i_width, p_dec->fmt_in.video.i_height );
+        return VLC_EGENERIC;
     }
 
     /* Allocate the memory needed to store the decoder's structure */
-    if( ( p_dec->p_sys = p_sys =
-          (decoder_sys_t *)malloc(sizeof(decoder_sys_t)) ) == NULL )
+    decoder_sys_t *p_sys = calloc(1, sizeof(*p_sys));
+    if( unlikely(p_sys == NULL) )
         return VLC_ENOMEM;
-    /* Misc init */
-    p_dec->p_sys->b_packetizer = false;
-    p_sys->b_invert = 0;
 
     if( (int)p_dec->fmt_in.video.i_height < 0 )
     {
@@ -141,13 +104,10 @@ static int OpenDecoder( vlc_object_t *p_this )
             (unsigned int)(-(int)p_dec->fmt_in.video.i_height);
         p_sys->b_invert = true;
     }
-
-    if( p_dec->fmt_in.video.i_width <= 0 || p_dec->fmt_in.video.i_height <= 0 )
-    {
-        msg_Err( p_dec, "invalid display size %dx%d",
-                 p_dec->fmt_in.video.i_width, p_dec->fmt_in.video.i_height );
-        return VLC_EGENERIC;
-    }
+    if( !p_dec->fmt_in.video.i_visible_width )
+        p_dec->fmt_in.video.i_visible_width = p_dec->fmt_in.video.i_width;
+    if( !p_dec->fmt_in.video.i_visible_height )
+        p_dec->fmt_in.video.i_visible_height = p_dec->fmt_in.video.i_height;
 
     es_format_Copy( &p_dec->fmt_out, &p_dec->fmt_in );
 
@@ -162,50 +122,22 @@ static int OpenDecoder( vlc_object_t *p_this )
         date_Init( &p_sys->pts, 25, 1 );
     }
 
-    /* Find out p_vdec->i_raw_size */
-    video_format_Setup( &p_dec->fmt_out.video, p_dec->fmt_in.i_codec,
-                        p_dec->fmt_in.video.i_width,
-                        p_dec->fmt_in.video.i_height,
-                        p_dec->fmt_in.video.i_sar_num,
-                        p_dec->fmt_in.video.i_sar_den );
-    picture_t picture;
-    picture_Setup( &picture, p_dec->fmt_out.i_codec,
-                   p_dec->fmt_in.video.i_width,
-                   p_dec->fmt_in.video.i_height, 0, 1 );
-    p_sys->i_raw_size = 0;
-    for( int i = 0; i < picture.i_planes; i++ )
+    for( unsigned i = 0; i < dsc->plane_count; i++ )
     {
-        p_sys->i_raw_size += picture.p[i].i_visible_pitch *
-                             picture.p[i].i_visible_lines;
-        p_sys->planes[i] = picture.p[i];
+        unsigned pitch = p_dec->fmt_in.video.i_width * dsc->pixel_size
+                         * dsc->p[i].w.num / dsc->p[i].w.den;
+        unsigned lines = p_dec->fmt_in.video.i_height
+                         * dsc->p[i].h.num / dsc->p[i].h.den;
+
+        p_sys->pitches[i] = pitch;
+        p_sys->lines[i] = lines;
+        p_sys->size += pitch * lines;
     }
 
-    if( !p_dec->fmt_in.video.i_sar_num || !p_dec->fmt_in.video.i_sar_den )
-    {
-        p_dec->fmt_out.video.i_sar_num = 1;
-        p_dec->fmt_out.video.i_sar_den = 1;
-    }
-
-    /* Set callbacks */
-    p_dec->pf_decode_video = (picture_t *(*)(decoder_t *, block_t **))
-        DecodeBlock;
-    p_dec->pf_packetize    = (block_t *(*)(decoder_t *, block_t **))
-        DecodeBlock;
-
+    p_dec->p_sys           = p_sys;
     return VLC_SUCCESS;
 }
 
-static int OpenPacketizer( vlc_object_t *p_this )
-{
-    decoder_t *p_dec = (decoder_t*)p_this;
-
-    int i_ret = OpenDecoder( p_this );
-
-    if( i_ret == VLC_SUCCESS ) p_dec->p_sys->b_packetizer = true;
-
-    return i_ret;
-}
-
 /****************************************************************************
  * DecodeBlock: the whole thing
  ****************************************************************************
@@ -214,13 +146,11 @@ static int OpenPacketizer( vlc_object_t *p_this )
 static void *DecodeBlock( decoder_t *p_dec, block_t **pp_block )
 {
     decoder_sys_t *p_sys = p_dec->p_sys;
-    block_t *p_block;
-    void *p_buf;
 
-    if( !pp_block || !*pp_block ) return NULL;
-
-    p_block = *pp_block;
+    if( pp_block == NULL || *pp_block == NULL )
+        return NULL;
 
+    block_t *p_block = *pp_block;
 
     if( p_block->i_pts <= VLC_TS_INVALID && p_block->i_dts <= VLC_TS_INVALID &&
         !date_Get( &p_sys->pts ) )
@@ -244,29 +174,17 @@ static void *DecodeBlock( decoder_t *p_dec, block_t **pp_block )
         date_Set( &p_sys->pts, p_block->i_dts );
     }
 
-    if( p_block->i_buffer < p_sys->i_raw_size )
+    if( p_block->i_buffer < p_sys->size )
     {
         msg_Warn( p_dec, "invalid frame size (%zu < %zu)",
-                  p_block->i_buffer, p_sys->i_raw_size );
+                  p_block->i_buffer, p_sys->size );
 
         block_Release( p_block );
         return NULL;
     }
 
-    if( p_sys->b_packetizer )
-    {
-        p_buf = SendFrame( p_dec, p_block );
-    }
-    else
-    {
-        p_buf = DecodeFrame( p_dec, p_block );
-    }
-
-    /* Date management: 1 frame per packet */
-    date_Increment( &p_sys->pts, 1 );
     *pp_block = NULL;
-
-    return p_buf;
+    return p_block;
 }
 
 /*****************************************************************************
@@ -274,40 +192,56 @@ static void *DecodeBlock( decoder_t *p_dec, block_t **pp_block )
  *****************************************************************************/
 static void FillPicture( decoder_t *p_dec, block_t *p_block, picture_t *p_pic )
 {
-    int i_plane;
     decoder_sys_t *p_sys = p_dec->p_sys;
-    uint8_t *p_src = p_block->p_buffer;
+    const uint8_t *p_src = p_block->p_buffer;
 
-    for( i_plane = 0; i_plane < p_pic->i_planes; i_plane++ )
-    {
-        int i_pitch = p_pic->p[i_plane].i_pitch;
-        int i_visible_pitch = p_sys->planes[i_plane].i_visible_pitch;
-        int i_visible_lines = p_sys->planes[i_plane].i_visible_lines;
-        uint8_t *p_dst = p_pic->p[i_plane].p_pixels;
-        uint8_t *p_dst_end = p_dst+i_pitch*i_visible_lines;
+    if( p_sys->b_invert )
+        for( int i = 0; i < p_pic->i_planes; i++ )
+        {
+            uint8_t *p_dst = p_pic->p[i].p_pixels
+                         + (p_pic->p[i].i_pitch * p_pic->p[i].i_visible_lines);
 
-        if( p_sys->b_invert )
-            for( p_dst_end -= i_pitch; p_dst <= p_dst_end;
-                 p_dst_end -= i_pitch, p_src += i_visible_pitch )
-                vlc_memcpy( p_dst_end, p_src, i_visible_pitch );
-        else
-            for( ; p_dst < p_dst_end;
-                 p_dst += i_pitch, p_src += i_visible_pitch )
-                vlc_memcpy( p_dst, p_src, i_visible_pitch );
-    }
+            for( int x = 0; x < p_pic->p[i].i_visible_lines; x++ )
+            {
+                p_dst -= p_pic->p[i].i_pitch;
+                memcpy( p_dst, p_src, p_pic->p[i].i_visible_pitch );
+                p_src += p_sys->pitches[i];
+            }
+
+            p_src += p_sys->pitches[i]
+                   * (p_sys->lines[i] - p_pic->p[i].i_visible_lines);
+        }
+    else
+        for( int i = 0; i < p_pic->i_planes; i++ )
+        {
+            uint8_t *p_dst = p_pic->p[i].p_pixels;
+
+            for( int x = 0; x < p_pic->p[i].i_visible_lines; x++ )
+            {
+                memcpy( p_dst, p_src, p_pic->p[i].i_visible_pitch );
+                p_src += p_sys->pitches[i];
+                p_dst += p_pic->p[i].i_pitch;
+            }
+
+            p_src += p_sys->pitches[i]
+                   * (p_sys->lines[i] - p_pic->p[i].i_visible_lines);
+        }
 }
 
 /*****************************************************************************
  * DecodeFrame: decodes a video frame.
  *****************************************************************************/
-static picture_t *DecodeFrame( decoder_t *p_dec, block_t *p_block )
+static picture_t *DecodeFrame( decoder_t *p_dec, block_t **pp_block )
 {
+    block_t *p_block = DecodeBlock( p_dec, pp_block );
+    if( p_block == NULL )
+        return NULL;
+
     decoder_sys_t *p_sys = p_dec->p_sys;
-    picture_t *p_pic;
 
     /* Get a new picture */
-    p_pic = decoder_NewPicture( p_dec );
-    if( !p_pic )
+    picture_t *p_pic = decoder_NewPicture( p_dec );
+    if( p_pic == NULL )
     {
         block_Release( p_block );
         return NULL;
@@ -315,7 +249,10 @@ static picture_t *DecodeFrame( decoder_t *p_dec, block_t *p_block )
 
     FillPicture( p_dec, p_block, p_pic );
 
-    p_pic->date = date_Get( &p_sys->pts );
+    /* Date management: 1 frame per packet */
+    p_pic->date = date_Get( &p_dec->p_sys->pts );
+    date_Increment( &p_sys->pts, 1 );
+
     if( p_block->i_flags & BLOCK_FLAG_INTERLACED_MASK )
     {
         p_pic->b_progressive = false;
@@ -332,64 +269,76 @@ static picture_t *DecodeFrame( decoder_t *p_dec, block_t *p_block )
     return p_pic;
 }
 
+static int OpenDecoder( vlc_object_t *p_this )
+{
+    decoder_t *p_dec = (decoder_t *)p_this;
+
+    int ret = OpenCommon( p_dec );
+    if( ret == VLC_SUCCESS )
+        p_dec->pf_decode_video = DecodeFrame;
+    return ret;
+}
+
 /*****************************************************************************
  * SendFrame: send a video frame to the stream output.
  *****************************************************************************/
-static block_t *SendFrame( decoder_t *p_dec, block_t *p_block )
+static block_t *SendFrame( decoder_t *p_dec, block_t **pp_block )
 {
+    block_t *p_block = DecodeBlock( p_dec, pp_block );
+    if( p_block == NULL )
+        return NULL;
+
     decoder_sys_t *p_sys = p_dec->p_sys;
 
+    /* Date management: 1 frame per packet */
     p_block->i_dts = p_block->i_pts = date_Get( &p_sys->pts );
+    date_Increment( &p_sys->pts, 1 );
 
     if( p_sys->b_invert )
     {
-        picture_t pic;
-        uint8_t *p_tmp, *p_pixels;
-        int i, j;
-
-        /* Fill in picture_t fields */
-        picture_Setup( &pic, p_dec->fmt_out.i_codec,
-                       p_dec->fmt_out.video.i_width,
-                       p_dec->fmt_out.video.i_height, 0, 1 );
-
-        if( !pic.i_planes )
+        block_t *out = block_Alloc( p_block->i_buffer );
+        if( likely(out != NULL) )
         {
-            msg_Err( p_dec, "unsupported chroma" );
-            return p_block;
-        }
+            block_CopyProperties( out, p_block );
 
-        p_tmp = malloc( pic.p[0].i_pitch );
-        if( !p_tmp )
-            return p_block;
-        p_pixels = p_block->p_buffer;
-        for( i = 0; i < pic.i_planes; i++ )
-        {
-            int i_pitch = pic.p[i].i_pitch;
-            uint8_t *p_top = p_pixels;
-            uint8_t *p_bottom = p_pixels + i_pitch *
-                (pic.p[i].i_visible_lines - 1);
+            const uint8_t *p_src = p_block->p_buffer;
+            uint8_t *p_pixels = out->p_buffer;
 
-            for( j = 0; j < pic.p[i].i_visible_lines / 2; j++ )
+            for( unsigned i = 0; i < PICTURE_PLANE_MAX; i++ )
             {
-                vlc_memcpy( p_tmp, p_bottom, pic.p[i].i_visible_pitch  );
-                vlc_memcpy( p_bottom, p_top, pic.p[i].i_visible_pitch  );
-                vlc_memcpy( p_top, p_tmp, pic.p[i].i_visible_pitch  );
-                p_top += i_pitch;
-                p_bottom -= i_pitch;
-            }
+                unsigned pitch = p_sys->pitches[i];
+                unsigned lines = p_sys->lines[i];
+                uint8_t *p_dst = p_pixels + (pitch * lines);
 
-            p_pixels += i_pitch * pic.p[i].i_lines;
+                for( unsigned x = 0; x < lines; x++ )
+                {
+                    p_dst -= p_sys->pitches[i];
+                    memcpy( p_dst, p_src, p_sys->pitches[i] );
+                    p_src += p_sys->pitches[i];
+                }
+            }
         }
-        free( p_tmp );
+        block_Release( p_block );
+        p_block = out;
     }
 
     return p_block;
 }
 
-/*****************************************************************************
- * CloseDecoder: decoder destruction
- *****************************************************************************/
-static void CloseDecoder( vlc_object_t *p_this )
+static int OpenPacketizer( vlc_object_t *p_this )
+{
+    decoder_t *p_dec = (decoder_t *)p_this;
+
+    int ret = OpenCommon( p_dec );
+    if( ret == VLC_SUCCESS )
+        p_dec->pf_packetize = SendFrame;
+    return ret;
+}
+
+/**
+ * Common deinitialization
+ */
+static void CloseCommon( vlc_object_t *p_this )
 {
     decoder_t *p_dec = (decoder_t*)p_this;
     free( p_dec->p_sys );
