@@ -2,7 +2,7 @@
  * subtitle.c: Demux for subtitle text files.
  *****************************************************************************
  * Copyright (C) 1999-2007 VLC authors and VideoLAN
- * $Id: c4402edfb9b9c02121b7037c4ae907a9eb914439 $
+ * $Id: f5634e8d75f18723b4238f9ad13f5f0f2bfcf84c $
  *
  * Authors: Laurent Aimar <fenrir@via.ecp.fr>
  *          Derk-Jan Hartman <hartman at videolan dot org>
@@ -166,6 +166,10 @@ struct demux_sys_t
         float f_total;
         float f_factor;
     } mpsub;
+    struct
+    {
+        char *psz_start;
+    } sami;
 };
 
 static int  ParseMicroDvd   ( demux_t *, subtitle_t *, int );
@@ -258,6 +262,7 @@ static int Open ( vlc_object_t *p_this )
 
     p_sys->jss.b_inited       = false;
     p_sys->mpsub.b_inited     = false;
+    p_sys->sami.psz_start     = NULL;
 
     /* Get the FPS */
     f_fps = var_CreateGetFloat( p_demux, "sub-original-fps" ); /* FIXME */
@@ -1255,7 +1260,9 @@ static int  ParseSami( demux_t *p_demux, subtitle_t *p_subtitle, int i_idx )
     char text[8192]; /* Arbitrary but should be long enough */
 
     /* search "Start=" */
-    if( !( s = ParseSamiSearch( txt, NULL, "Start=" ) ) )
+    s = ParseSamiSearch( txt, p_sys->sami.psz_start, "Start=" );
+    p_sys->sami.psz_start = NULL;
+    if( !s )
         return VLC_EGENERIC;
 
     /* get start value */
@@ -1271,7 +1278,6 @@ static int  ParseSami( demux_t *p_demux, subtitle_t *p_subtitle, int i_idx )
 
     i_text = 0;
     text[0] = '\0';
-    const char *psz_startline = s;
     /* now get all txt until  a "Start=" line */
     for( ;; )
     {
@@ -1288,10 +1294,9 @@ static int  ParseSami( demux_t *p_demux, subtitle_t *p_subtitle, int i_idx )
             {
                 c = '\n';
             }
-            else if( strcasestr( s, "Start=" ) &&
-                     psz_startline != s )
+            else if( strcasestr( s, "Start=" ) )
             {
-                TextPreviousLine( txt );
+                p_sys->sami.psz_start = s;
                 break;
             }
             s = ParseSamiSearch( txt, s, ">" );
@@ -1667,7 +1672,7 @@ static int ParseJSS( demux_t *p_demux, subtitle_t *p_subtitle, int i_idx )
 
     demux_sys_t  *p_sys = p_demux->p_sys;
     text_t       *txt = &p_sys->txt;
-    char         *psz_text, *psz_orig = NULL;
+    char         *psz_text, *psz_orig;
     char         *psz_text2, *psz_orig2;
     int h1, h2, m1, m2, s1, s2, f1, f2;
 
@@ -1683,7 +1688,6 @@ static int ParseJSS( demux_t *p_demux, subtitle_t *p_subtitle, int i_idx )
     /* Parse the main lines */
     for( ;; )
     {
-        free(psz_orig);
         const char *s = TextGetLine( txt );
         if( !s )
             return VLC_EGENERIC;
@@ -1774,10 +1778,16 @@ static int ParseJSS( demux_t *p_demux, subtitle_t *p_subtitle, int i_idx )
                 sscanf( &psz_text[shift], "%d", &p_sys->jss.i_time_resolution );
                 break;
             }
+            free( psz_orig );
+            continue;
+        }
+        else
+            /* Unkown type line, probably a comment */
+        {
+            free( psz_orig );
+            continue;
         }
     }
-    free( psz_orig );
-    psz_orig = NULL;
 
     while( psz_text[ strlen( psz_text ) - 1 ] == '\\' )
     {
