@@ -2,7 +2,7 @@
  * interface_widgets.cpp : Custom widgets for the main interface
  ****************************************************************************
  * Copyright (C) 2006-2010 the VideoLAN team
- * $Id: 8c30ac02124b13f486c7a7d1375dbd79de44c907 $
+ * $Id: f43344608896ab0500b9f223b3d552b9db386495 $
  *
  * Authors: Clément Stenac <zorglub@videolan.org>
  *          Jean-Baptiste Kempf <jb@videolan.org>
@@ -58,6 +58,9 @@
 
 #ifdef Q_WS_X11
 #   include <X11/Xlib.h>
+#   ifdef HAVE_XI
+#       include <X11/extensions/XInput2.h>
+#   endif
 #   include <qx11info_x11.h>
 #endif
 
@@ -148,7 +151,25 @@ WId VideoWidget::request( int *pi_x, int *pi_y,
 
     XGetWindowAttributes( dpy, w, &attr );
     attr.your_event_mask &= ~(ButtonPressMask|ButtonReleaseMask);
+    attr.your_event_mask &= ~PointerMotionMask;
     XSelectInput( dpy, w, attr.your_event_mask );
+# ifdef HAVE_XI
+    int n;
+    XIEventMask *xi_masks = XIGetSelectedEvents( dpy, w, &n );
+    if( xi_masks != NULL )
+    {
+        for( int i = 0; i < n; i++ )
+            if( xi_masks[i].mask_len >= 1 )
+            {
+                xi_masks[i].mask[0] &= ~XI_ButtonPressMask;
+                xi_masks[i].mask[0] &= ~XI_ButtonReleaseMask;
+                xi_masks[i].mask[0] &= ~XI_MotionMask;
+            }
+
+        XISelectEvents( dpy, w, xi_masks, n );
+        XFree( xi_masks );
+    }
+# endif
 #endif
     sync();
     return stable->winId();
