@@ -2,7 +2,7 @@
  * simple_preferences.hpp : Simple prefs
  ****************************************************************************
  * Copyright (C) 2006 the VideoLAN team
- * $Id: ecc136df559b0739c0dfb95195a80795596e8926 $
+ * $Id: 8e2bf6e24895cae64d8423223dabafa54d6b3342 $
  *
  * Authors: Clément Stenac <zorglub@videolan.org>
  *
@@ -78,7 +78,7 @@ class SPrefsCatList : public QWidget
 {
     Q_OBJECT
 public:
-    SPrefsCatList( intf_thread_t *, QWidget *, bool );
+    SPrefsCatList( intf_thread_t *, QWidget * );
     virtual ~SPrefsCatList() {};
 private:
     intf_thread_t *p_intf;
@@ -92,7 +92,7 @@ class SPrefsPanel : public QWidget
 {
     Q_OBJECT
 public:
-    SPrefsPanel( intf_thread_t *, QWidget *, int, bool );
+    SPrefsPanel( intf_thread_t *, QWidget *, int );
     virtual ~SPrefsPanel();
     void apply();
     void clean();
@@ -126,6 +126,7 @@ private slots:
     void langChanged( int );
 #ifdef _WIN32
     void assoDialog();
+    void updateCheckBoxes( QTreeWidgetItem*, int );
     void saveAsso();
 #endif
     void configML();
