@@ -2,7 +2,7 @@
  * profile_selector.cpp : A small profile selector and editor
  ****************************************************************************
  * Copyright (C) 2009 the VideoLAN team
- * $Id: 858a8ec64c5bfb263c43e489df9b83c07b587fe2 $
+ * $Id: 65d8bf1e18b6b90464b3b6841d0d9a0087070227 $
  *
  * Authors: Jean-Baptiste Kempf <jb@videolan.org>
  *
@@ -508,19 +508,21 @@ inline void VLCProfileEditor::registerCodecs()
     ui.button->setProperty( "capstream", stream );\
     ui.button->setProperty( "capchaps", chaps );\
     CONNECT( ui.button, clicked(bool), this, muxSelected() );
-    SETMUX( PSMux, "ps", "mux_ps",  true, true, false, true, false, true )
-    SETMUX( TSMux, "ts", "mux_ts",  true, true, false, true, true, false )
+    SETMUX( PSMux, "ps", "ps",  true, true, false, true, false, true )
+    SETMUX( TSMux, "ts", "ts",  true, true, false, true, true, false )
     SETMUX( WEBMux, "webm", "avformat", true, true, false, false, true, false )
-    SETMUX( MPEG1Mux, "mpeg1", "mux_ps", true, true, false, false, false, false )
-    SETMUX( OggMux, "ogg", "mux_ogg", true, true, false, false, true, true )
-    SETMUX( ASFMux, "asf", "mux_asf", true, true, false, true, true, true )
-    SETMUX( MOVMux, "mp4", "mux_mp4", true, true, true, true, true, false )
-    SETMUX( WAVMux, "wav", "mux_wav", false, true, false, false, false, false )
-    SETMUX( RAWMux, "raw", "mux_dummy", true, true, false, false, false, false )
+    SETMUX( MPEG1Mux, "mpeg1", "ps", true, true, false, false, false, false )
+    SETMUX( OggMux, "ogg", "ogg", true, true, false, false, true, true )
+    SETMUX( ASFMux, "asf", "asf", true, true, false, true, true, true )
+    SETMUX( MOVMux, "mp4", "mp4", true, true, true, true, true, false )
+    SETMUX( WAVMux, "wav", "wav", false, true, false, false, false, false )
+    SETMUX( FLACMux, "flac", "dummy", false, true, false, false, false, false )
+    SETMUX( MP3Mux, "mp3", "dummy", false, true, false, false, false, false )
+    SETMUX( RAWMux, "raw", "dummy", true, true, false, false, false, false )
     SETMUX( FLVMux, "flv", "avformat", true, true, false, false, true, false )
     SETMUX( MKVMux, "mkv", "avformat", true, true, true, true, true, true )
-    SETMUX( AVIMux, "avi", "mux_avi", true, true, false, false, false, false )
-    SETMUX( MJPEGMux, "mpjpeg", "mux_mpjpeg", true, false, false, false, false, false )
+    SETMUX( AVIMux, "avi", "avi", true, true, false, false, false, false )
+    SETMUX( MJPEGMux, "mpjpeg", "mpjpeg", true, false, false, false, false, false )
 #undef SETMUX
 
 #define ADD_VCODEC( name, fourcc ) \
@@ -603,7 +605,8 @@ void VLCProfileEditor::muxSelected()
                     QString( "<img src=\":/menu/info\"/> %1" )
                     .arg( qtr( "This muxer is not provided directly by VLC: It could be missing." ) )
                     );
-    else if ( !caps["muxers"].contains( current->property("module").toString() ) )
+    else if ( !caps["muxers"].contains( current->property("module").toString() ) &&
+              !caps["muxers"].contains( "mux_" + current->property("module").toString() ) )
         ui.muxerwarning->setText(
                     QString( "<img src=\":/menu/quit\"/> %1" )
                     .arg( qtr( "This muxer is missing. Using this profile will fail" ) )
