@@ -2,7 +2,7 @@
  * demux.c :  Lua playlist demux module
  *****************************************************************************
  * Copyright (C) 2007-2008 the VideoLAN team
- * $Id: a84fd663ebaeb96f5357670f229b35f572012b1f $
+ * $Id: 13ccf61673429aca2499ec610b4af30117fab495 $
  *
  * Authors: Antoine Cellerier <dionoea at videolan tod org>
  *
@@ -30,14 +30,8 @@
 
 #include <assert.h>
 
-#include <vlc_common.h>
-#include <vlc_demux.h>
-#include <vlc_url.h>
-#include <vlc_strings.h>
-
 #include "vlc.h"
 #include "libs.h"
-#include "libs/playlist.h"
 
 
 /*****************************************************************************
@@ -127,9 +121,9 @@ static const luaL_Reg p_reg_parse[] =
  * the script pointed by psz_filename.
  *****************************************************************************/
 static int probe_luascript( vlc_object_t *p_this, const char * psz_filename,
-                            void * user_data )
+                            const luabatch_context_t *p_context )
 {
-    VLC_UNUSED(user_data);
+    VLC_UNUSED(p_context);
     demux_t * p_demux = (demux_t *)p_this;
 
     p_demux->p_sys->psz_filename = strdup(psz_filename);
@@ -169,7 +163,7 @@ static int probe_luascript( vlc_object_t *p_this, const char * psz_filename,
     }
 
     /* Load and run the script(s) */
-    if( luaL_dofile( L, psz_filename ) )
+    if( vlclua_dofile( VLC_OBJECT(p_demux), L, psz_filename ) )
     {
         msg_Warn( p_demux, "Error loading script %s: %s", psz_filename,
                   lua_tostring( L, lua_gettop( L ) ) );
