@@ -2,7 +2,7 @@
  * vlc.c: Generic lua interface functions
  *****************************************************************************
  * Copyright (C) 2007-2008 the VideoLAN team
- * $Id: 6f9b50528db293c636fa55e534fa4231899a8a8d $
+ * $Id: dd8987bcfe0c78963dd14f0ffc88a9715b58f93e $
  *
  * Authors: Antoine Cellerier <dionoea at videolan tod org>
  *          Pierre d'Herbemont <pdherbemont # videolan.org>
@@ -32,16 +32,14 @@
 #include <assert.h>
 #include <sys/stat.h>
 
-#include <vlc_common.h>
+#include "vlc.h"
+
 #include <vlc_plugin.h>
-#include <vlc_meta.h>
 #include <vlc_charset.h>
 #include <vlc_fs.h>
 #include <vlc_services_discovery.h>
 #include <vlc_stream.h>
 
-#include "vlc.h"
-
 /*****************************************************************************
  * Module descriptor
  *****************************************************************************/
@@ -215,7 +213,7 @@ int vlclua_dir_list( const char *luadirname, char ***pppsz_dir_list )
         i++;
     free( datadir );
 
-#if !(defined(__APPLE__) || defined(_WIN32) || defined(__OS2__))
+#if !(defined(__APPLE__) || defined(_WIN32))
     char *psz_libpath = config_GetLibDir();
     if( likely(psz_libpath != NULL) )
     {
@@ -262,7 +260,7 @@ void vlclua_dir_list_free( char **ppsz_dir_list )
  *****************************************************************************/
 int vlclua_scripts_batch_execute( vlc_object_t *p_this,
                                   const char * luadirname,
-                                  int (*func)(vlc_object_t *, const char *, void *),
+                                  int (*func)(vlc_object_t *, const char *, const luabatch_context_t *),
                                   void * user_data)
 {
     char **ppsz_dir_list = NULL;
@@ -379,12 +377,17 @@ void vlclua_read_meta_data( vlc_object_t *p_this, lua_State *L,
     TRY_META( "date", Date );
     TRY_META( "setting", Setting );
     TRY_META( "url", URL );
-    TRY_META( "language", Language );
+    TRY_META( "language",  Language );
     TRY_META( "nowplaying", NowPlaying );
-    TRY_META( "publisher", Publisher );
-    TRY_META( "encodedby", EncodedBy );
-    TRY_META( "arturl", ArtURL );
-    TRY_META( "trackid", TrackID );
+    TRY_META( "publisher",  Publisher );
+    TRY_META( "encodedby",  EncodedBy );
+    TRY_META( "arturl",     ArtURL );
+    TRY_META( "trackid",    TrackID );
+    TRY_META( "director",   Director );
+    TRY_META( "season",     Season );
+    TRY_META( "episode",    Episode );
+    TRY_META( "show_name",  ShowName );
+    TRY_META( "actors",     Actors );
 }
 
 #undef vlclua_read_custom_meta_data
@@ -666,7 +669,7 @@ static int vlc_sd_probe_Open( vlc_object_t *obj )
                 free( psz_filename );
                 goto error;
             }
-            if( luaL_dofile( L, psz_filename ) )
+            if( vlclua_dofile( VLC_OBJECT(probe), L, psz_filename ) )
             {
 
                 msg_Err( probe, "Error loading script %s: %s", psz_filename,
@@ -832,15 +835,23 @@ int vlclua_add_modules_path( lua_State *L, const char *psz_filename )
 }
 
 /** Replacement for luaL_dofile, using VLC's input capabilities */
-int vlclua_dofile( vlc_object_t *p_this, lua_State *L, const char *uri )
+int vlclua_dofile( vlc_object_t *p_this, lua_State *L, const char *curi )
 {
-    if( !strstr( uri, "://" ) )
-        return luaL_dofile( L, uri );
-    if( !strncasecmp( uri, "file://", 7 ) )
-        return luaL_dofile( L, uri + 7 );
+    char *uri = ToLocaleDup( curi );
+    if( !strstr( uri, "://" ) ) {
+        int ret = luaL_dofile( L, uri );
+        free( uri );
+        return ret;
+    }
+    if( !strncasecmp( uri, "file://", 7 ) ) {
+        int ret = luaL_dofile( L, uri + 7 );
+        free( uri );
+        return ret;
+    }
     stream_t *s = stream_UrlNew( p_this, uri );
     if( !s )
     {
+        free( uri );
         return 1;
     }
     int64_t i_size = stream_Size( s );
@@ -849,6 +860,7 @@ int vlclua_dofile( vlc_object_t *p_this, lua_State *L, const char *uri )
     {
         // FIXME: read the whole stream until we reach the end (if no size)
         stream_Delete( s );
+        free( uri );
         return 1;
     }
     int64_t i_read = stream_Read( s, p_buffer, (int) i_size );
@@ -859,5 +871,6 @@ int vlclua_dofile( vlc_object_t *p_this, lua_State *L, const char *uri )
         i_ret = lua_pcall( L, 0, LUA_MULTRET, 0 );
     stream_Delete( s );
     free( p_buffer );
+    free( uri );
     return i_ret;
 }
