@@ -2,7 +2,7 @@
  * blend2.cpp: Blend one picture with alpha onto another picture
  *****************************************************************************
  * Copyright (C) 2012 Laurent Aimar
- * $Id: 03c92e5eada2327352d2243d43fe65c43c1b1b29 $
+ * $Id: befe88616eaaa49ef0d12b10d4901696f876ad60 $
  *
  * Authors: Laurent Aimar <fenrir _AT_ videolan _DOT_ org>
  *
@@ -297,9 +297,29 @@ public:
     void merge(unsigned dx, const CPixel &spx, unsigned a, bool)
     {
         uint8_t *dst = getPointer(dx);
-        ::merge(&dst[offset_r], spx.i, a);
-        ::merge(&dst[offset_g], spx.j, a);
-        ::merge(&dst[offset_b], spx.k, a);
+        if (has_alpha) {
+            // Handle different cases of existing alpha in the
+            // destination buffer. If the existing alpha is 0,
+            // the RGB components should be copied as is and
+            // alpha set to 'a'. If the existing alpha is 255,
+            // this should behave just as the non-alpha case below.
+
+            // First blend the existing color based on its
+            // alpha with the incoming color.
+            ::merge(&dst[offset_r], spx.i, 255 - dst[offset_a]);
+            ::merge(&dst[offset_g], spx.j, 255 - dst[offset_a]);
+            ::merge(&dst[offset_b], spx.k, 255 - dst[offset_a]);
+            // Now blend in the new color on top with the normal formulas.
+            ::merge(&dst[offset_r], spx.i, a);
+            ::merge(&dst[offset_g], spx.j, a);
+            ::merge(&dst[offset_b], spx.k, a);
+            // Finally set dst_a = (255 * src_a + prev_a * (255 - src_a))/255.
+            ::merge(&dst[offset_a], 255, a);
+        } else {
+            ::merge(&dst[offset_r], spx.i, a);
+            ::merge(&dst[offset_g], spx.j, a);
+            ::merge(&dst[offset_b], spx.k, a);
+        }
     }
     void nextLine()
     {
@@ -405,6 +425,7 @@ struct convertBits {
 };
 typedef convertBits< 9, 8> convert8To9Bits;
 typedef convertBits<10, 8> convert8To10Bits;
+typedef convertBits<16, 8> convert8To16Bits;
 
 struct convertRgbToYuv8 {
     convertRgbToYuv8(const video_format_t *, const video_format_t *) {}
@@ -543,6 +564,7 @@ static const struct {
     RGB(VLC_CODEC_RGB16,    CPictureRGB16,    convertRgbToRgbSmall),
     RGB(VLC_CODEC_RGB24,    CPictureRGB24,    convertNone),
     RGB(VLC_CODEC_RGB32,    CPictureRGB32,    convertNone),
+    RGB(VLC_CODEC_RGBA,     CPictureRGBA,     convertNone),
 
     YUV(VLC_CODEC_YV9,      CPictureYV9,      convertNone),
     YUV(VLC_CODEC_I410,     CPictureI410_8,   convertNone),
@@ -577,9 +599,11 @@ static const struct {
 #ifdef WORDS_BIGENDIAN
     YUV(VLC_CODEC_I444_9B,  CPictureI444_16,  convert8To9Bits),
     YUV(VLC_CODEC_I444_10B, CPictureI444_16,  convert8To10Bits),
+    YUV(VLC_CODEC_I444_16B, CPictureI444_16,  convert8To16Bits),
 #else
     YUV(VLC_CODEC_I444_9L,  CPictureI444_16,  convert8To9Bits),
     YUV(VLC_CODEC_I444_10L, CPictureI444_16,  convert8To10Bits),
+    YUV(VLC_CODEC_I444_16L, CPictureI444_16,  convert8To16Bits),
 #endif
 
     YUV(VLC_CODEC_YUYV,     CPictureYUYV,     convertNone),
