@@ -133,7 +133,6 @@ void *vlc_custom_create (vlc_object_t *parent, size_t length,
     vlc_mutex_init (&priv->var_lock);
     vlc_cond_init (&priv->var_wait);
     priv->pipes[0] = priv->pipes[1] = -1;
-    atomic_init (&priv->alive, true);
     atomic_init (&priv->refs, 1);
     priv->pf_destructor = NULL;
     priv->prev = NULL;
@@ -157,6 +156,7 @@ void *vlc_custom_create (vlc_object_t *parent, size_t length,
 
         /* Attach the parent to its child (structure lock needed) */
         libvlc_lock (obj->p_libvlc);
+        atomic_init (&priv->alive, atomic_load (&papriv->alive));
         priv->next = papriv->first;
         if (priv->next != NULL)
             priv->next->prev = priv;
@@ -170,6 +170,7 @@ void *vlc_custom_create (vlc_object_t *parent, size_t length,
         obj->i_flags = 0;
         obj->p_libvlc = self;
         obj->p_parent = NULL;
+        atomic_init (&priv->alive, true);
         priv->next = NULL;
         vlc_mutex_init (&(libvlc_priv (self)->structure_lock));
 
@@ -437,10 +438,10 @@ vlc_object_t *vlc_object_find_name( vlc_object_t *p_this, const char *psz_name )
     /* This was officially deprecated on August 19 2009. For the convenience of
      * wannabe code janitors, this is the list of names that remain used
      * and unfixed since then. */
-    static const char const bad[][11] = { "adjust", "clone", "colorthres",
+    static const char bad[][11] = { "adjust", "clone", "colorthres",
         "erase", "extract", "gradient", "logo", "marq", "motionblur", "puzzle",
         "rotate", "sharpen", "transform", "v4l2", "wall" };
-    static const char const poor[][13] = { "invert", "magnify", "motiondetect",
+    static const char poor[][13] = { "invert", "magnify", "motiondetect",
         "psychedelic", "ripple", "wave" };
     if( bsearch( psz_name, bad, 15, 11, (void *)strcmp ) == NULL
      && bsearch( psz_name, poor, 6, 13, (void *)strcmp ) == NULL )
@@ -543,7 +544,7 @@ bool vlc_object_alive(vlc_object_t *obj)
 
 #undef vlc_list_children
 /**
- * Gets the list of children of an objects, and increment their reference
+ * Gets the list of children of an object, and increment their reference
  * count.
  * @return a list (possibly empty) or NULL in case of error.
  */
